#!/bin/sh

# Build script for texi2html
# Author: Ejis <ejis@mailoo.org>

# Homepage: http://www.nongnu.org/texi2html/


set -e


SOFTNAME=texi2html
VERSION=1.82
ZENVER=64
BUILD=1

MARCH=i486
FLAGS="-O2 -march=$MARCH -mtune=i686"

CWD=$(pwd)

PKG=$SOFTNAME-$VERSION-$MARCH-$ZENVER.$BUILD

SOFTDIR=$CWD/$SOFTNAME-$VERSION
PKGDIR=$CWD/$PKG

PKGFILE=$PKGDIR.txz
MD5=$PKGDIR.md5
SRC=$PKGDIR.src
DEP=$PKGDIR.dep
LOG=$PKGDIR.log

SRCFILES=(
	$SOFTNAME-$VERSION.tar.gz
)
SRCURLS=(
	'http://download.savannah.gnu.org/releases/texi2html'
)

SRCLINKS=(
	${SRCURLS[0]}/${SRCFILES[0]}
)

DOC=(
	$SOFTDIR/AUTHORS
	$SOFTDIR/ChangeLog
	$SOFTDIR/COPYING
	$SOFTDIR/INSTALL
	$SOFTDIR/NEWS
	$SOFTDIR/README
	$SOFTDIR/TODO
)

EXTRADEPS=(
)

LESSDEPS=(
	'fakeroot'
)


# Check for source files and download them if necessary

if [ ! -f ${SRCFILES[0]} ]; then
	wget -c -t 0 -T 50 -w 0 ${SRCLINKS[0]}
fi


# Erase the previous build files

rm -rf $SOFTDIR $PKGDIR $MD5 $SRC $DEP $LOG
mkdir -p $PKG


# Build

build () {
	
	echo ""
	echo "-----Building-----"
	echo ""
	
	tar -xvf $CWD/${SRCFILES[0]}

	cd $SOFTDIR

	export CFLAGS=$FLAGS
	export CXXFLAGS=$FLAGS

	./configure \
		--prefix=/usr \
		--localstatedir=/var \
		--sysconfdir=/etc \
		--mandir=/usr/man \
		--infodir=/usr/info
	make -j2
	make DESTDIR=$PKGDIR install

}


# Packaging

packaging () {
	
	echo ""
	echo "-----Packaging-----"
	echo ""
	
	( cd $PKG

	mkdir -p $PKGDIR/install
	mkdir -p $PKGDIR/usr/src/$SOFTNAME-$VERSION
	mkdir -p $PKGDIR/usr/doc/$SOFTNAME-$VERSION


           #|-----handy-ruler------------------------------------------------------|
	cat > $PKGDIR/install/slack-desc <<EOF
$SOFTNAME: $SOFTNAME - Open Source Texinfo to HTML Conversion Script
$SOFTNAME:
$SOFTNAME: Texi2HTML is a Perl script which converts Texinfo source files
$SOFTNAME: to HTML output, licensed under the GNU General Public License,
$SOFTNAME: version 2, or any later version.
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME:
EOF

	
	# Redundent
	
	if [ -d $PKGDIR/usr/share/doc ]; then
		mv $PKGDIR/usr/share/doc/$SOFTNAME/* $PKGDIR/usr/doc/$SOFTNAME-$VERSION/
		rm -rvf $PKGDIR/usr/share/doc
	fi
	
	if [ -d $PKGDIR/etc ]; then
		
		for file in $(ls $PKGDIR/etc/); do
			
			if [ -f $PKGDIR/etc/$file ]; then
				mv -v $PKGDIR/etc/$file $PKGDIR/etc/$file.new
			fi
			
		done
		
	fi

	find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
		xargs strip --strip-unneeded 2> /dev/null || true
	find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
		xargs strip --strip-unneeded 2> /dev/null || true

	if [ -d $PKGDIR/usr/man ]; then
		
		( cd $PKGDIR/usr/man
			find . -type f -exec gzip -9 {} \;
			for i in $( find . -type l ) ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
		)
		
	fi

	if [ -d $PKGDIR/usr/info ]; then
		
		rm -f $PKGDIR/usr/info/dir
		gzip -9 $PKGDIR/usr/info/*.info*
		
	fi

	find . -name perllocal.pod \
		-o -name ".packlist" \
		-o -name "*.bs" \
		| xargs rm -f


	cp -v $CWD/build-$SOFTNAME.sh $PKGDIR/usr/src/$SOFTNAME-$VERSION/

	cp -rv	${DOC[@]} $PKGDIR/usr/doc/$SOFTNAME-$VERSION/


	# fix permissions and ownership
	chown -R root:root .
	find . -perm 777 -exec chmod 755 {} \;
	find . -perm 775 -exec chmod 755 {} \;
	find . -perm 666 -exec chmod 644 {} \;
	find . -perm 664 -exec chmod 644 {} \;
	find . -perm 600 -exec chmod 644 {} \;
	find . -perm 444 -exec chmod 644 {} \;
	find . -perm 400 -exec chmod 644 {} \;
	find . -perm 440 -exec chmod 644 {} \;
	find . -perm 511 -exec chmod 755 {} \;
	find . -perm 711 -exec chmod 755 {} \;
	find . -perm 555 -exec chmod 755 {} \;


	/sbin/makepkg -l y -c n $PKGFILE )


	echo 'Creating .md5 file'
	md5sum $PKG.txz >> $MD5

	echo 'Creating .src file'
	for link in ${SRCLINKS[@]}; do
		echo $link >> $SRC
	done

	echo 'Checking for dependencies'
	deps=$(depfinder $PKGFILE)
	
	for dep in ${EXTRADEPS[@]}; do
		deps="$deps,$dep"
	done
	
	for dep in ${LESSDEPS[@]}; do
		deps=${deps/$dep/}
	done
	
	order=$(echo ${deps//,/ } | sort -d)
	echo ${order// /,} >> $DEP

	echo "Removing build directories"
	rm -rf $SOFTDIR $PKG
}


LANG=C build 2>&1 | tee $LOG
LANG=C packaging 2>&1 | tee -a $LOG
